package com.ruoyi.ai.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ruoyi.ai.domain.AiWork;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * ai作品Service接口
 * 
 * @author shi
 * @date 2025-11-25
 */
public interface IAiWorkService {

    /**
     * 查询ai作品
     * 
     * @param id ai作品主键
     * @return ai作品
     */
    AiWork selectAiWorkById(Long id);

    /**
     * 查询ai作品列表
     * 
     * @param aiWork ai作品
     * @return ai作品集合
     */
    List<AiWork> selectAiWorkList(AiWork aiWork);

    /**
     * 分页查询ai作品列表
     *
     * @param aiWork ai作品
     * @return ai作品集合
     */
    IPage<AiWork> selectAiWorkPage(Page page, AiWork aiWork);

    /**
     * 新增ai作品
     * 
     * @param aiWork ai作品
     * @return 结果
     */
    int insertAiWork(AiWork aiWork);

    /**
     * 修改ai作品
     * 
     * @param aiWork ai作品
     * @return 结果
     */
    int updateAiWork(AiWork aiWork);

    /**
     * 批量删除ai作品
     * 
     * @param ids 需要删除的ai作品主键集合
     * @return 结果
     */
    int deleteAiWorkByIds(Long[] ids);

    /**
     * 删除ai作品信息
     * 
     * @param id ai作品主键
     * @return 结果
     */
    int deleteAiWorkById(Long id);
}
